==> miniorange_saml_idp-8.x-2.12.tar.gz: miniorange_saml_idp/src/MiniorangeSAMLIdpSupport.php <==
<?php

namespace Drupal\miniorange_saml_idp;

/**
 * @file
 * Contains miniOrange Support class.
 */

class MiniorangeSAMLIdpSupport {
  public $email;
  public $phone;
  public $query;
  public $query_type;

  public function __construct( $email, $phone, $query, $query_type ) {
    $this->email = $email;
    $this->phone = $phone;
    $this->query = $query;
    $this->query_type = $query_type;
  }

  /**
   * Send support query.
   * Send request for demo
   */
	public function sendSupportQuery() {

        $modules_info = system_get_info('module', 'miniorange_saml_idp');
        $modules_version = $modules_info['version'];

        if( $this->query_type === 'Demo Request' ){
            $this->query = 'Demo request for ' . $this->phone . ' .<br> '. $this->query;
        }

        $this->query = '[Drupal-8 SAML IDP ' . $this->query_type . ' | ' .$modules_version. '] ' . $this->query;

        $fields = array (
            'company' => $_SERVER['SERVER_NAME'],
            'email'   => $this->email,
            'phone'   => $this->query_type != 'Demo Request' ? $this->phone : '',
            'ccEmail' => 'drupalsupport@xecurify.com',
            'query'   => $this->query
        );
        $field_string = json_encode( $fields );
        $url = MiniorangeSAMLIdpConstants::BASE_URL . '/moas/rest/customer/contact-us';
        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($ch, CURLOPT_ENCODING, "");
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
        curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);
        curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array (
            'Content-Type: application/json',
            'charset: UTF-8',
            'Authorization: Basic'
        ));
        curl_setopt($ch, CURLOPT_POST, TRUE);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);
        $content = curl_exec( $ch );
        if ( curl_errno($ch ) ) {
            \Drupal::logger('miniorange_saml_idp')->error("cURL Error at <strong>sendSupportQuery</strong> function of <strong>MiniorangeSAMLIdpSupport.php</strong> file: " . curl_error( $ch ));
            return FALSE;
        }
        curl_close($ch);
        return TRUE;
	}
}

==> miniorange_saml_idp-8.x-2.14.tar.gz: miniorange_saml_idp/src/MiniorangeSAMLIdpSupport.php <==
<?php

namespace Drupal\miniorange_saml_idp;

/**
 * @file
 * Contains miniOrange Support class.
 */

class MiniorangeSAMLIdpSupport {
  public $email;
  public $phone;
  public $query;
  public $query_type;

  public function __construct( $email, $phone, $query, $query_type ) {
    $this->email = $email;
    $this->phone = $phone;
    $this->query = $query;
    $this->query_type = $query_type;
  }

  /**
   * Send support query.
   * Send request for demo
   */
	public function sendSupportQuery() {

		$modulesInfo = \Drupal::service('extension.list.module')->getExtensionInfo('miniorange_saml_idp');
        $modulesVersion = $modulesInfo['version'];

        if( $this->query_type === 'Demo Request' ){
            $this->query = 'Demo request for ' . $this->phone . ' .<br> '. $this->query;
        }

        $this->query = '[Drupal ' . Utilities::mo_get_drupal_core_version() . ' SAML IDP ' . $this->query_type . ' | ' .$modulesVersion. '] ' . $this->query;

        $fields = array (
            'company' => $_SERVER['SERVER_NAME'],
            'email'   => $this->email,
            'phone'   => $this->query_type != 'Demo Request' ? $this->phone : '',
            'ccEmail' => 'drupalsupport@xecurify.com',
            'query'   => $this->query
        );
        $field_string = json_encode( $fields );
        $url = MiniorangeSAMLIdpConstants::BASE_URL . '/moas/rest/customer/contact-us';
        $ch = curl_init($url);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
        curl_setopt($ch, CURLOPT_ENCODING, "");
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
        curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);
        curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array (
            'Content-Type: application/json',
            'charset: UTF-8',
            'Authorization: Basic'
        ));
        curl_setopt($ch, CURLOPT_POST, TRUE);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);
        $content = curl_exec( $ch );
        if ( curl_errno($ch ) ) {
            \Drupal::logger('miniorange_saml_idp')->error("cURL Error at <strong>sendSupportQuery</strong> function of <strong>MiniorangeSAMLIdpSupport.php</strong> file: " . curl_error( $ch ));
            return FALSE;
        }
        curl_close($ch);
        return TRUE;
	}
}
